<?php
/*
This file is part of Mailboy.

Mailboy is free software: you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.

Mailboy is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with Mailboy.  If not, see <http://www.gnu.org/licenses/>.
*/


// Update Mailboy..


// Define current DB version
$current_db_version = 6;


// Get DB version
$db_version = $cnx->select_field("value", "mailboy_cfg", "WHERE `key` = 'db_version' LIMIT 1");

// If it doesn't exist, it's probably because the table does not exist
if (!$db_version) {
	$content['status'][] = "SYSTEM UPDATE: creating new table `mailboy_cfg`";
	$cnx->query("CREATE TABLE IF NOT EXISTS `mailboy_cfg` ( `key` varchar(16) NOT NULL, `value` VARCHAR(256) NOT NULL, UNIQUE KEY `key` (`key`) ) ENGINE=InnoDB DEFAULT CHARSET=utf8;", 0);
	$cnx->query("INSERT INTO `mailboy_cfg` (`key`, `value`) VALUES ('db_version', '0');", 0);
	$db_version = 0;
}

// If db_version exists AND is lower than the current version, else don't do anything
if ($db_version < $current_db_version AND is_valid_id($db_version)) {
	set_status("SYSTEM UPDATE: Applying updates");
	while ($db_version < $current_db_version) {
		$db_version++;
		update_db($db_version);
		update_db_version_number($db_version);
	}
}


function update_db_version_number($v) {
	global $cnx;
	$cnx->query("UPDATE `mailboy_cfg` SET `value` = '$v' WHERE `mailboy_cfg`.`key` = 'db_version' LIMIT 1;", 0);
}

function update_db($v) {
	global $available_langs;
	global $cnx;
	switch($v) {
		case 1:
			// update user table: add 'mail' and 'suspend'
			$cnx->query("ALTER TABLE `virtual_users` ADD `mail` TINYINT(1) NOT NULL DEFAULT '1',
			ADD `xmpp` TINYINT(1) NOT NULL DEFAULT '0', ADD `suspend` TINYINT(1) NOT NULL DEFAULT '0'", 0);

			// Create optimised view for XMPP server
			$cnx->query("CREATE VIEW view_xmpp_users AS SELECT CONCAT(user, '@', name) AS email, password FROM virtual_users
			LEFT JOIN virtual_domains ON (virtual_users.domain_id = virtual_domains.id) WHERE `xmpp` = 1 AND `suspend` = 0;", 0);
		break;
		case 2:
			// Update view users and add optimised view for postfix/dovecot/amavis
			$cnx->query("DROP VIEW `view_users`", 0);

			// Full user view
			$cnx->query("CREATE VIEW view_users AS SELECT virtual_users.id AS uid, user, CONCAT(user, '@', name) AS email, password,
			quota_kb, quota_messages, name AS domain, virtual_domains.id AS domain_id, policy_name, policy_id, admin, xmpp, mail, suspend,
			GROUP_CONCAT(DISTINCT domain_admin_assoc.domain_id) AS admin_of_ids,
			GROUP_CONCAT((SELECT virtual_domains.name FROM virtual_domains WHERE domain_admin_assoc.domain_id = virtual_domains.id)) AS admin_of_names
			FROM virtual_users
			LEFT JOIN virtual_domains ON (virtual_users.domain_id = virtual_domains.id)
			LEFT JOIN policy ON (virtual_users.policy_id = policy.id)
			LEFT JOIN domain_admin_assoc ON (virtual_users.id = domain_admin_assoc.user_id)
			GROUP BY virtual_users.id;", 0);

			// Optimised view for mail servers
			$cnx->query("CREATE VIEW view_mail_users AS SELECT user, CONCAT(user, '@', name) AS email, password, quota_kb, quota_messages, policy_id FROM virtual_users
			LEFT JOIN virtual_domains ON (virtual_users.domain_id = virtual_domains.id) WHERE `mail` =1 AND `suspend` =0;", 0);

			$cnx->query("ALTER TABLE `virtual_domains` ADD `default_xmpp` TINYINT(1) NOT NULL", 0);
			$cnx->query("ALTER TABLE `virtual_domains` ADD `default_mail` TINYINT(1) NOT NULL DEFAULT '1'", 0);
			$cnx->query("DROP VIEW `view_domains`", 0);
			$cnx->query("CREATE VIEW view_domains AS
			SELECT virtual_domains.id, virtual_domains.name, virtual_domains.default_policy, policy_name, policy.id AS policy_id,
			virtual_domains.default_quota_kb AS default_quota, virtual_domains.default_mail AS default_mail, virtual_domains.default_xmpp AS default_xmpp,
			(SELECT count(virtual_users.id) FROM virtual_users WHERE virtual_users.domain_id = virtual_domains.id) AS accounts,
			(SELECT count(virtual_aliases.id) FROM virtual_aliases WHERE virtual_aliases.domain_id = virtual_domains.id) AS aliases
			FROM virtual_domains
			LEFT JOIN policy ON (virtual_domains.default_policy = policy.id);", 0);
		break;
		case 3:
			// Add notes for relay domains
			$cnx->query("ALTER TABLE `relay_domains` ADD `note` text NOT NULL", 0);
		break;
		case 4:
			// Optimise Amavis' view
			$cnx->query("DROP VIEW `view_users_policies`;", 0);

			$cnx->query("CREATE VIEW view_users_policies AS
			SELECT email, virus_lover, spam_lover, banned_files_lover, bad_header_lover, bypass_virus_checks, bypass_spam_checks,
			bypass_banned_checks, bypass_header_checks, spam_modifies_subj, spam_quarantine_to, spam_tag_level, spam_tag2_level, spam_kill_level
			FROM view_mail_users, policy
			WHERE (view_mail_users.policy_id = policy.id);", 0);
		break;
		case 5:
			$cnx->query("ALTER TABLE `virtual_domains` ADD ml TINYINT( 1 ) UNSIGNED NOT NULL DEFAULT '0';", 0);
			$cnx->query("DROP VIEW `view_domains`;", 0);
			$cnx->query("CREATE VIEW view_domains AS
			SELECT virtual_domains.id, virtual_domains.name, virtual_domains.default_policy, policy_name, policy.id AS policy_id,
			virtual_domains.default_quota_kb AS default_quota, virtual_domains.default_mail AS default_mail, virtual_domains.default_xmpp AS default_xmpp, virtual_domains.ml AS ml,
			(SELECT count(virtual_users.id) FROM virtual_users WHERE virtual_users.domain_id = virtual_domains.id) AS accounts,
			(SELECT count(virtual_aliases.id) FROM virtual_aliases WHERE virtual_aliases.domain_id = virtual_domains.id) AS aliases
			FROM virtual_domains
			LEFT JOIN policy ON (virtual_domains.default_policy = policy.id);", 0);
			$cnx->query("CREATE TABLE IF NOT EXISTS `virtual_mailing_lists` (
			id INT(11) UNSIGNED NOT NULL AUTO_INCREMENT,
			domain_id INT(11) UNSIGNED NOT NULL,
			ml VARCHAR(64) NOT NULL,
			transport VARCHAR(127) NOT NULL,
			PRIMARY KEY (`id`),
			UNIQUE KEY `ml` (`domain_id`,`ml`),
			FOREIGN KEY (`domain_id`) REFERENCES `virtual_domains` (`id`) ON DELETE CASCADE
			) ENGINE=InnoDB  DEFAULT CHARSET=utf8;", 0);
			$cnx->query("CREATE VIEW view_mailing_lists AS
			SELECT virtual_mailing_lists.id, domain_id, ml, name as domain, CONCAT(ml, '@', name) AS mailing_list, transport
			FROM virtual_mailing_lists
			LEFT JOIN virtual_domains ON (virtual_mailing_lists.domain_id = virtual_domains.id);", 0);
		break;
		case 6:
			$cnx->query("ALTER TABLE `domain_access` add `bounce_message` TEXT NOT NULL", 0);
			$cnx->query("ALTER TABLE `ip_access` add `bounce_message` TEXT NOT NULL", 0);
			// Add algo to password field - futur proofing..
			$cnx->query("UPDATE `virtual_users` SET `password` = CONCAT('{PLAIN-MD5}', password) WHERE CHAR_LENGTH(`password`) = 32", 0);
			// Make sure password field is up to 255 for everyone
			$cnx->query("ALTER TABLE `virtual_users` CHANGE `password` `password` VARCHAR(255) CHARACTER SET utf8 COLLATE utf8_general_ci NOT NULL;");
		break;
	}
}


?>
