<?php
/*
Mailboy - A Php/MySQL application that offers a web based interface
to administer an email server. It can be used by the server administrator
as well as the email users.
(c) 2013-2018 Emmanuel Revah - manu-at-manurevah.com
https://mailboy.manurevah.com/

This file is part of Mailboy.

Mailboy is free software: you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.

Mailboy is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with Mailboy.  If not, see <http://www.gnu.org/licenses/>.
*/


session_name("Mailboy");
session_start();
session_regenerate_id();

// Calm down error reporting
error_reporting(E_ALL&~E_NOTICE);

$mailboy_version = "0.7.4";

require_once('config/db_config.php');
require_once('inc/functions.php');
require_once('inc/mysql_class.php');
require_once('inc/form_maker.php');

// MySQL init
$cnx = new MysqlThing($db_host, $db_user, $db_pass, $db_database);

// it's here for now
if ($_POST['logout']) {
	unset($_GET);
	unset($_POST);
	unset($_SESSION);
	session_destroy();
	$content['status'][] = "logged out";
}


// FIXME make these things a bit .. ... better.
// Regular expresions for different verifications. Use config.php to overwrite these
$reg_email_or_domain = "#^[@a-z0-9\-\._+\!\#]{1,127}$#i";
$reg_domain = "#^[a-z0-9\.\-]{1,127}$#i";
$reg_account = "#^[a-z0-9\-\._+\!\#]{1,127}$#i"; // (email prefix)


require_once('config/config.php');
require_once('inc/user_update.php');
require_once('inc/update.php');

$page = $_GET['page'];

// This var is used to display menu items below TODO move all this to a proper config page or something
if (am_i_server_admin(1)) { $show_this_page = 1; }

// pages
$admin_pages = array(
	'domains' => array(
		'title' => "Domains",
		'menu' => 1
	),
	'accounts' => array(
		'title' => "Accounts",
		'menu' => 0
	),
	'relay_domains' => array(
		'title' => "Relay domains",
		'menu' => $show_this_page
	),
	'sender_acls' => array(
		'title' => "ACLs",
		'menu' => $show_this_page
	)
);
$user_pages = array(
	'account_details' => array(
			'title' => "My account",
			'menu' => 1
	),
	'policies' => array(
			'title' => "Filters",
			'menu' => 1
	)
);
$public_pages = array(
	'login' => array(
			'title' => "Login page",
			'menu' => 0
	)
);


// Get data from config and merge the stuff
$admin_pages = array_merge($admin_pages, $user_pages, $public_pages);
$user_pages = array_merge($user_pages, $public_pages);

// define authorised pages array
if (am_i_admin_of_anything()) {
	$content['menu'] = array_merge($admin_pages, $user_pages, $public_pages);
} elseif (am_i_user()) {
	$pages_allowed = $user_pages;
	$content['menu'] = $user_pages = array_merge($user_pages, $public_pages);
} else {
	$pages_allowed = $public_pages;
	$content['menu'] = $public_pages;
}


// Genlink and set active
foreach ($content['menu'] as $k => $v) {
	$content['menu'][$k]['link'] = genlink("page=$k");
	if ($page == $k) {
		$content['menu'][$k]['active'] = 1;
	}
}


if (array_key_exists($page, $content['menu'])) {
	// OKAY
} elseif (!am_i_user()) {
	$page = "login";
} elseif (!strlen($page)) {
	//$page = "home";
	// Do nothing ?
} else {
	$page = "404";
}


if ($page) {
	if (file_exists("pages/$page.php")) {
		require_once("pages/$page.php");
	} else {
		$page = "404";
	}
}

// Include our base template
require_once("templates/".$cfg['template']."/main.php");
?>
