#!/bin/bash

# Get password from config file
source "../config/db_config.sh"

# Make sure file is not empty
if [[ -z "$MAILUSER" || -z "$MAILUSERPASS" || -z $DBHOST || -z $DBNAME ]] ; then
	echo -e "\nA variable is empty. Please check config/db_config.sh and retry\n"
	exit
fi

# write config files for Postfix
echo "user = $MAILUSER
password = $MAILUSERPASS
hosts = $DBHOST
dbname = $DBNAME
query = SELECT 1 FROM virtual_domains WHERE name='%s'" > /etc/postfix/mysql-virtual-mailbox-domains.cf

echo "user = $MAILUSER
password = $MAILUSERPASS
hosts = $DBHOST
dbname = $DBNAME
query = SELECT 1 FROM view_mail_users WHERE email='%s'" > /etc/postfix/mysql-virtual-mailbox-maps.cf

echo "user = $MAILUSER
password = $MAILUSERPASS
hosts = $DBHOST
dbname = $DBNAME
query = SELECT destination FROM view_aliases WHERE email='%s'" > /etc/postfix/mysql-virtual-alias-maps.cf

echo "user = $MAILUSER
password = $MAILUSERPASS
hosts = $DBHOST
dbname = $DBNAME
query = SELECT email FROM view_mail_users WHERE email='%s'" > /etc/postfix/mysql-email2email.cf

echo "user = $MAILUSER
password = $MAILUSERPASS
hosts = $DBHOST
dbname = $DBNAME
query = SELECT domain FROM relay_domains WHERE domain like '%s'" > /etc/postfix/mysql-relay-domains.cf

echo "user = $MAILUSER
password = $MAILUSERPASS
hosts = $DBHOST
dbname = $DBNAME
query = SELECT CONCAT (state, ' ', bounce_message) FROM domain_access WHERE domain = '%s'" > /etc/postfix/mysql-smtpd_sender_restrictions.cf

echo "user = $MAILUSER
password = $MAILUSERPASS
hosts = $DBHOST
dbname = $DBNAME
query = SELECT CONCAT (state, ' ', bounce_message) FROM ip_access WHERE ip = '%s'" > /etc/postfix/mysql-ip-access.cf

echo "user = $MAILUSER
password = $MAILUSERPASS
hosts = $DBHOST
dbname = $DBNAME
query = SELECT mailing_list FROM view_mailing_lists WHERE mailing_list='%s'" > /etc/postfix/mysql-virtual-mailing-lists.cf

echo "user = $MAILUSER
password = $MAILUSERPASS
hosts = $DBHOST
dbname = $DBNAME
query = SELECT transport FROM view_mailing_lists WHERE mailing_list='%s'" > /etc/postfix/mysql-mailing-list-transport.cf


# Fix file permissions
chgrp postfix /etc/postfix/mysql-*.cf
chmod u=rw,g=r,o= /etc/postfix/mysql-*.cf

# Backup main.cf
cp /etc/postfix/main.cf /etc/postfix/main.cf.ORIG

# Write to main.cf

# Various settings
echo -e "\n# Extra TLS setting" >> /etc/postfix/main.cf
postconf -e smtpd_tls_security_level=may

# Mailboy
echo -e "\n# Mailboy" >> /etc/postfix/main.cf
postconf -e virtual_uid_maps=static:5000
postconf -e virtual_gid_maps=static:5000
postconf -e virtual_mailbox_domains=mysql:/etc/postfix/mysql-virtual-mailbox-domains.cf
postconf -e virtual_mailbox_maps=mysql:/etc/postfix/mysql-virtual-mailbox-maps.cf
postconf -e virtual_alias_maps=mysql:/etc/postfix/mysql-virtual-alias-maps.cf,mysql:/etc/postfix/mysql-email2email.cf

echo -e "\n# Relay domains" >> /etc/postfix/main.cf
postconf -e relay_domains=mysql:/etc/postfix/mysql-relay-domains.cf
postconf -e relay_recipient_maps=

echo -e "\n# SMTPD restrictions" >> /etc/postfix/main.cf
postconf -e smtpd_helo_restrictions='permit_mynetworks, permit_sasl_authenticated, check_client_access mysql:/etc/postfix/mysql-ip-access.cf, reject_non_fqdn_helo_hostname, reject_invalid_helo_hostname'
postconf -e smtpd_client_restrictions='permit_mynetworks, permit_sasl_authenticated, check_client_access mysql:/etc/postfix/mysql-ip-access.cf, reject_unknown_client_hostname'
postconf -e smtpd_recipient_restrictions='permit_mynetworks, permit_sasl_authenticated, check_client_access mysql:/etc/postfix/mysql-ip-access.cf, reject_unauth_destination, reject_unknown_sender_domain, check_policy_service unix:private/policy-spf'

# SPF - timeout
echo -e "\n# SPF timeout" >> /etc/postfix/main.cf
postconf -e policy-spf_time_limit=3600s

# Dovecot
echo -e "\n# Dovecot" >> /etc/postfix/main.cf
postconf -e virtual_transport=dovecot
postconf -e dovecot_destination_recipient_limit=1
postconf -e smtpd_sasl_type=dovecot
postconf -e smtpd_sasl_path=private/auth
postconf -e smtpd_sasl_auth_enable=yes

# Amavis
echo -e "\n# Amavis" >> /etc/postfix/main.cf
postconf -e content_filter=smtp-amavis:[127.0.0.1]:10024
postconf -e receive_override_options=no_address_mappings

# DKIM
echo -e "\n# DKIM" >> /etc/postfix/main.cf
postconf -e milter_protocol=2
postconf -e milter_default_action=accept
postconf -e smtpd_milters=inet:localhost:8892
postconf -e non_smtpd_milters=inet:localhost:8892
